<?php
/* --------------------------------------------------------------
   OvistoServiceFactory.inc.php 2018-01-31
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/
use HubPublic\Http\CurlRequest;

/**
 * Class OvistoServiceFactory
 *
 * @category   Core
 * @package    Ovisto
 * @subpackage Factories
 */
class OvistoServiceFactory
{
    /**
     * @var string $dirFsCatalog
     */
    protected static $dirFsCatalog = DIR_FS_CATALOG;
    
    /**
     * @var string $rootDirectory
     */
    protected static $rootDirectory;
    
    /**
     * @var string $curl
     */
    protected static $curl;
    
    
    /**
     * @return \OvistoCouponService
     */
    public static function createCouponService()
    {
        return MainFactory::create(OvistoCouponService::class, self::createCouponRepository());
    }
    
    
    /**
     * @return \OvistoLogoService
     */
    public static function createLogoService()
    {
        return MainFactory::create(OvistoLogoService::class, self::createLogoStorageReader());
    }
    
    
    /**
     * @return \OvistoCouponRepository
     */
    protected static function createCouponRepository()
    {
        return MainFactory::create(OvistoCouponRepository::class, self::createCouponReader(),
            self::createCacheManager());
    }
    
    
    /**
     * @return \OvistoCouponReader
     */
    protected static function createCouponReader()
    {
        return MainFactory::create(OvistoCouponReader::class, self::createCouponFactory(), self::root());
    }
    
    
    /**
     * @return \OvistoCacheManager
     */
    protected static function createCacheManager()
    {
        return MainFactory::create(OvistoCacheManager::class, self::createCouponFactory(),
            self::createExpirationStrategy(), self::curl(), self::root());
    }
    
    
    /**
     * @return \OvistoCouponFactory
     */
    protected static function createCouponFactory()
    {
        return MainFactory::create(OvistoCouponFactory::class, self::createLogoStorageWriter(),
            self::createCouponCodeReader());
    }
    
    
    /**
     * @return \OvistoExpirationStrategy
     */
    protected static function createExpirationStrategy()
    {
        return MainFactory::create(OvistoExpirationStrategy::class);
    }
    
    
    /**
     * @return \OvistoLogoStorageReader
     */
    protected static function createLogoStorageReader()
    {
        return MainFactory::create(OvistoLogoStorageReader::class, self::createLogoFactory(), static::root());
    }
    
    
    /**
     * @return \OvistoLogoFactory
     */
    protected static function createLogoFactory()
    {
        return MainFactory::create(OvistoLogoFactory::class, self::createLogoStorageWriter());
    }
    
    
    /**
     * @return \OvistoLogoStorageWriter
     */
    protected static function createLogoStorageWriter()
    {
        return MainFactory::create(OvistoLogoStorageWriter::class, static::curl(), static::root());
    }
    
    
    /**
     * @return \OvistoCouponCodeReader
     */
    protected static function createCouponCodeReader()
    {
        return MainFactory::create(OvistoCouponCodeReader::class, static::curl());
    }
    
    
    /**
     * @return $curl
     */
    protected static function curl()
    {
        if (null === static::$curl) {
            static::$curl = new CurlRequest();
        }
        
        return static::$curl;
    }
    
    
    /**
     * @return $rootDirectory
     */
    protected static function root()
    {
        if (null === static::$rootDirectory) {
            static::$rootDirectory = new ExistingDirectory(static::$dirFsCatalog);
        }
        
        return static::$rootDirectory;
    }
}