<?php
/* --------------------------------------------------------------
   OvistoCouponRepository.inc.php 2018-01-29
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class OvistoCouponRepository
 */
class OvistoCouponRepository implements OvistoCouponRepositoryInterface
{
    /**
     * @var OvistoCouponReaderInterface $couponReader
     */
    protected $couponReader;
    
    /**
     * @var OvistoCacheManagerInterface $cacheManager
     */
    protected $cacheManager;
    
    
    /**
     * OvistoCouponRepository constructor.
     *
     * @param OvistoCouponReaderInterface $couponReader
     * @param OvistoCacheManagerInterface $cacheManager
     */
    public function __construct(OvistoCouponReaderInterface $couponReader, OvistoCacheManagerInterface $cacheManager)
    {
        $this->couponReader = $couponReader;
        $this->cacheManager = $cacheManager;
    }
    
    
    /**
     * Gets a coupon by its ID.
     * 
     * @param IdType $id
     *
     * @return OvistoCoupon
     */
    public function getCouponById(IdType $id)
    {
        $this->cacheManager->checkAndPerformRefresh();
    
        return $this->couponReader->getCouponById($id);
    }
    
    
    /**
     * Gets all available Ovisto coupons.
     *
     * @param IntType $limit
     * @param IntType $offset
     * 
     * @return OvistoCouponCollection
     */
    public function getAllCoupons(IntType $limit, IntType $offset)
    {
        $this->cacheManager->checkAndPerformRefresh();
        
        return $this->couponReader->getAllCoupons($limit, $offset);
    }
    
    
    /**
     * Gets the total number of available Ovisto coupons.
     * 
     * @return int
     */
    public function getCouponQuantity()
    {
        return $this->couponReader->getCouponQuantity();
    }
}